pub struct Renderer {
pub instance: Instance,
pub adapter: Adapter,
pub device: Device,
pub queue: Queue,
pub bind_group_layout_tex: BindGroupLayout,
pub bind_group_layout_uni: BindGroupLayout,
pub uniform_buffer: Buffer,
pub uniform_bind_group: BindGroup,
/* private fields */
}Fields
instance: Instanceadapter: Adapterdevice: Devicequeue: Queuebind_group_layout_tex: BindGroupLayoutbind_group_layout_uni: BindGroupLayoutuniform_buffer: Bufferuniform_bind_group: BindGroupImplementations
Sourceimpl Renderer
impl Renderer
pub async fn new() -> Result<Self>
Sourcepub fn create_texture(&self, width: u32, height: u32) -> (Texture, BindGroup)
pub fn create_texture(&self, width: u32, height: u32) -> (Texture, BindGroup)
Creates a reusable RGBA8 texture with a matching bind group. Live
wallpapers upload new frame data into it via update_texture.
Sourcepub fn update_texture(
&self,
texture: &Texture,
rgba: &[u8],
width: u32,
height: u32,
)
pub fn update_texture( &self, texture: &Texture, rgba: &[u8], width: u32, height: u32, )
Replaces the contents of a texture created by create_texture.
pub fn load_texture(&self, image: &DynamicImage) -> Result<(Texture, BindGroup)>
pub fn update_uniforms(&self, uniforms: Uniforms)
Sourcepub fn render_frame(&self, request: FrameRequest<'_>) -> Result<FrameStatus>
pub fn render_frame(&self, request: FrameRequest<'_>) -> Result<FrameStatus>
Renders the given texture bind groups to a wgpu Surface for one frame. bg_bind = old wallpaper, new_bind = new wallpaper, transitioned by effect.