Module theme

Module theme 

Enums

ThemeError

Functions

check_provider_available
detect_matugen_loop_risk
Detects if matugen is the parent process, which could cause a loop.
dispatch_theme
run_hooks
Runs hook commands sequentially. User hooks output is preserved.
run_reload_list
Runs reload commands, via shell or pkill quietly (swallows failure if app isn’t running).