pub enum VideoError {
Show 18 variants
FileOpen {
path: PathBuf,
source: Error,
},
UnsupportedFormat(String),
NoVideoStream(PathBuf),
UnsupportedCodec(String),
HardwareDecoderInit {
backend: String,
source: Error,
},
HardwareDecoderFallback,
SoftwareDecoderInit(Error),
DecodeFailed(Error),
FormatConversionFailed(Error),
TextureUploadFailed(Error),
InvalidPts,
UnknownDuration,
SeekFailed(Duration, Error),
AdapterNotFound(String),
GpuResourceCreation(Error),
ChannelDisconnected,
QueueFull,
EndOfStream,
}Variants
FileOpen
UnsupportedFormat(String)
NoVideoStream(PathBuf)
UnsupportedCodec(String)
HardwareDecoderInit
HardwareDecoderFallback
SoftwareDecoderInit(Error)
DecodeFailed(Error)
FormatConversionFailed(Error)
TextureUploadFailed(Error)
InvalidPts
UnknownDuration
SeekFailed(Duration, Error)
AdapterNotFound(String)
GpuResourceCreation(Error)
ChannelDisconnected
QueueFull
EndOfStream
Implementations
Sourceimpl VideoError
impl VideoError
Sourcepub fn is_recoverable(&self) -> bool
pub fn is_recoverable(&self) -> bool
Returns true if this error is recoverable and playback can continue.
Returns true if this error indicates hardware acceleration is unavailable.