Enums
Functions
- check_
provider_ available - detect_
matugen_ loop_ risk - Detects if matugen is the parent process, which could cause a loop.
- dispatch_
theme - run_
hooks - Runs hook commands sequentially. User hooks output is preserved.
- run_
reload_ list - Runs reload commands, via shell or pkill quietly (swallows failure if app isn’t running).